--[[
Author: Starinnia
CPR is a combo points display addon based on Funkydude's BasicComboPoints
BanditsGuile.lua - A module for tracking the Bandit's Guile buffs
$Date: 2010-10-16 03:55:38 +0000 (Sat, 16 Oct 2010) $
$Revision: 158 $
Project Version: r161
contact: codemaster2010 AT gmail DOT com

Copyright (c) 2007-2010 Michael J. Murray aka Lyte of Lothar(US)
All rights reserved unless otherwise explicitly stated.
]]

if select(2, UnitClass("player")) ~= "ROGUE" then return end

local cpr = LibStub("AceAddon-3.0"):GetAddon("ComboPointsRedux")
local modName = "Bandits Guile"
local BanditsGuile = cpr:NewModule(modName, "AceConsole-3.0", "AceEvent-3.0")

local SHALLOW_INSIGHT = GetSpellInfo(84745)
local MODERATE_INSIGHT = GetSpellInfo(84746)
local DEEP_INSIGHT = GetSpellInfo(84747)

function BanditsGuile:OnInitialize()
	self.abbrev = "BG"
	self.MAX_POINTS = 3
	self.displayName = GetSpellInfo(84654)
end

function BanditsGuile:OnEnable()
	if not cpr.db.profile.modules[modName].disableGraphics then
		if not self.graphics then
			self.graphics = cpr:MakeGraphicsFrame(modName, self.MAX_POINTS)
		end
		self.graphics:Show()
	end
	if not cpr.db.profile.modules[modName].disableText then
		if not self.text then
			self.text = cpr:MakeTextFrame(modName)
		end
		self.text:Show()
	end
	
	self:RegisterEvent("UNIT_AURA")
end

function BanditsGuile:OnDisable()
	self.graphics:Hide()
	self.text:Hide()
	self:UnregisterAllEvents()
end

function BanditsGuile:UNIT_AURA(_, unit)
	if unit ~= "player" then return end
	
	local _, _, _, shallow = UnitBuff("player", SHALLOW_INSIGHT)
	local _, _, _, moderate = UnitBuff("player", MODERATE_INSIGHT)
	local _, _, _, deep = UnitBuff("player", DEEP_INSIGHT)
	
	local r, g, b
	if shallow then
		r, g, b = cpr:GetColorByPoints(modName, 1)
		
		self.graphics.points[1].icon:SetVertexColor(r, g, b)
		self.graphics.points[1]:Show()
		
		if self.text then self.text:SetNumPoints(1) end
	elseif moderate then
		r, g, b = cpr:GetColorByPoints(modName, 2)
		
		self.graphics.points[1].icon:SetVertexColor(r, g, b)
		self.graphics.points[2].icon:SetVertexColor(r, g, b)
		self.graphics.points[2]:Show()
		
		if self.text then self.text:SetNumPoints(2) end
	elseif deep then
		r, g, b = cpr:GetColorByPoints(modName, 3)
		
		self.graphics.points[1].icon:SetVertexColor(r, g, b)
		self.graphics.points[2].icon:SetVertexColor(r, g, b)
		self.graphics.points[3].icon:SetVertexColor(r, g, b)
		self.graphics.points[3]:Show()
		
		if self.text then self.text:SetNumPoints(3) end
	else
		for i = 1, self.MAX_POINTS do
			self.graphics.points[i]:Hide()
		end
		if self.text then self.text:SetNumPoints("") end
	end
end
